@@ -1,6 +1,6 @@
 /*
  *  Xtoolwait - wait for X client to map a window
- *  Copyright (C) 1995  Richard Huveneers <richard@hekkihek.hacom.nl>
+ *  Copyright (C) 1995-1999  Richard Huveneers <richard@hekkihek.hacom.nl>
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -51,11 +51,12 @@ options:\n\
    -version\n"
 #define MAINTAINER		"richard@hekkihek.hacom.nl"
 #define VERSION_MAJOR		1
-#define VERSION_MINOR		2
+#define VERSION_MINOR		3
 
 Display *dpy;
 char *programname, *childname;
 Atom xa_wm_state;
+int (*prevxerrhandler)(Display *, XErrorEvent *);
 
 void
 timeout(signo)
@@ -115,6 +116,26 @@ is_mapped(window)
     return 1;
 }
 
+int
+xerrhandler(d, e)
+    Display *d;
+    XErrorEvent *e;
+{
+    DPRINTF(("received X error (error code %d, major opcode %d)\n", (int) e->error_code, (int) e->request_code));
+
+    if ((int) e->error_code == BadWindow)
+    {
+        /*
+        ** This error occurs when a window is destroyed before we got a
+        ** chance to examine it.
+        */
+        DPRINTF(("  BadWindow error: ignored\n"));
+        return 0;
+    }
+
+    return prevxerrhandler(d, e);
+}
+
 int
 main(argc, argv)
     int argc;
@@ -192,6 +213,8 @@ main(argc, argv)
 
     childname = argv[arg];
 
+    prevxerrhandler = XSetErrorHandler(xerrhandler);
+
     dpy = XOpenDisplay(displayname);
     if (!dpy) {
         (void) fprintf(stderr, "%s: unable to open display (%s), NOT executing %s\n",
